pub enum TemplateErrorKind {
UnclosedBrace,
UnknownVariable,
PhaseRestricted,
Unavailable,
InvalidSpec,
}Expand description
Why ExtensionError::Template failed (RBP-F006).
Variants
UnclosedBrace
Template contained { without a matching }.
UnknownVariable
{name} is not a known template variable.
PhaseRestricted
Variable is valid only in the other expansion phase.
Variable is known but not available in this context.
InvalidSpec
Expand/preexec spec is incomplete or contradictory.